User's Guide
============

The User's Guide should provide you with all the information necessary to build
your C++ project with Clang Build.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   first_steps.rst
   customisations.rst
   multiple_targets.rst
   multiple_projects.rst
   inheritance.rst
   platform_dependence.rst
   bundling.rst
   scripting.rst
   defaults.rst